@@ -2,6 +2,7 @@
 
 from .client import AnyAdsSDK, init, get_sdk_instance
 from .exceptions import AnyAdsException, InitializationError, APIError
+from . import integrations
 
 
 __all__ = [
@@ -11,6 +12,7 @@ __all__ = [
     "AnyAdsException",
     "InitializationError",
     "APIError",
+    "integrations",
 ]
 
 import logging
